import { ReadModelRunStatus } from '@resolve-js/readmodel-base';

const status = async (...args) => {
  var _ref;

  const [pool, readModelName, includeRuntimeStatus] = args;
  const state = await pool.getReplicationState(pool);
  let runStatus = ReadModelRunStatus.DELIVER;

  if (state.statusAndData.status === 'criticalError') {
    runStatus = ReadModelRunStatus.ERROR;
  } else if (state.paused) {
    runStatus = ReadModelRunStatus.SKIP;
  }

  let error = null;

  if (state.statusAndData.status === 'criticalError' || state.statusAndData.status === 'serviceError') {
    var _state$statusAndData$, _state$statusAndData$2;

    error = {
      name: (_state$statusAndData$ = state.statusAndData.data.name) !== null && _state$statusAndData$ !== void 0 ? _state$statusAndData$ : 'Error',
      message: (_state$statusAndData$2 = state.statusAndData.data.message) !== null && _state$statusAndData$2 !== void 0 ? _state$statusAndData$2 : 'Unknown error'
    };
  }

  let result = {
    eventSubscriber: readModelName,
    deliveryStrategy: 'inline-ledger',
    successEvent: state.successEvent != null ? state.successEvent : {
      type: 'Init'
    },
    failedEvent: null,
    errors: error != null ? [error] : null,
    cursor: state.iterator ? (_ref = state.iterator.cursor) !== null && _ref !== void 0 ? _ref : null : null,
    status: runStatus
  };

  if (includeRuntimeStatus) {
    result = Object.assign(result, {
      isAlive: state.statusAndData.status !== 'criticalError'
    });
  }

  return result;
};

export default status;
//# sourceMappingURL=status.js.map